<?xml version="1.0" encoding="utf-8"?>

<!--
Denne transformasjonen ekstraherer en vokabularfil i tekstfrom fra en *_vocab.xml-fil

-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:d="http://www.apple.com/DTDs/DictionaryService-1.0.rng"
    xmlns="http://www.w3.org/1999/xhtml"
>
    <!-- Custom function -->
    <xsl:template name="replace-string">
        <xsl:param name="text"/>
        <xsl:param name="replace"/>
        <xsl:param name="with"/>
        <xsl:choose>
            <xsl:when test="contains($text, $replace)">
                <xsl:value-of select="substring-before($text, $replace)"/>
                <xsl:value-of select="$with"/>
                <xsl:call-template name="replace-string">
                    <xsl:with-param name="text" select="substring-after($text, $replace)"/>
                    <xsl:with-param name="replace" select="$replace"/>
                    <xsl:with-param name="with" select="$with"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!-- Custom function -->
    <xsl:template name="replace_space_with_underscore">
        <xsl:param name="text"/>
        <xsl:call-template name="replace-string">
            <xsl:with-param name="text" select="$text"/>
            <xsl:with-param name="replace" select="' '"/>
            <xsl:with-param name="with" select="'_'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:output method="text" version="1.0" encoding="UTF-8"/>
    <xsl:strip-space elements="*"/>


    <xsl:template match="vocabulary">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="item">
        <xsl:for-each select="*">
            <xsl:value-of select="name(.)"/>
            <xsl:text>&#9;</xsl:text>
            <xsl:apply-templates select="."/>
            <xsl:text>&#9;</xsl:text>
        </xsl:for-each>
        <xsl:value-of select="@count"/>
        <xsl:text>&#10;</xsl:text>
    </xsl:template>
    
    <xsl:template match="complex_word|multiword">
        <xsl:call-template name="replace_space_with_underscore">
            <xsl:with-param name="text" select="@text"/>
        </xsl:call-template>
        <xsl:if test="@deadend">;deadend=<xsl:value-of select="@deadend"/></xsl:if>
        <xsl:text>&#9;</xsl:text>
        <xsl:for-each select="*">
            <xsl:if test="name(..) = 'multiword' and position() > 1">
                <xsl:text> </xsl:text>
            </xsl:if>
            <xsl:apply-templates select="."/>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="comma|titlestart|titleend|sentence_boundary">
        <xsl:text>&lt;</xsl:text><xsl:value-of select="name()"/><xsl:text>&gt;</xsl:text>
    </xsl:template>
    
    <xsl:template match="sil|fp|inhale|exhale|nasal|vowel|anonymized|incomprehensible">
        <xsl:text>&lt;</xsl:text><xsl:value-of select="name()"/><xsl:text>&gt;</xsl:text>
    </xsl:template>


    <xsl:template match="word|slang">
        <xsl:value-of select="@text"/>
        <xsl:if test="@deadend">;deadend=<xsl:value-of select="@deadend"/></xsl:if>
        <xsl:if test="@normalized">;normalized=<xsl:value-of select="@normalized"/></xsl:if>
        <xsl:if test="name(..) = 'item'">
        <xsl:text>&#9;_</xsl:text>
        </xsl:if>
    </xsl:template>
    
    
    
</xsl:stylesheet>
